RouteDependency class

A route owns one initialized generation of a dependency, not merely its type/tag. These callbacks become no-ops if that generation is replaced.

Constructors

RouteDependency({required void markAsDirty(), required bool delete()})
const

Properties

delete → bool Function()
final
hashCode → int
The hash code for this object.
no setterinherited
markAsDirty → void Function()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited