searchDelegate method
Implementation
SintDelegate searchDelegate(String? k) {
SintDelegate key;
if (k == null) {
key = Sint.rootController.rootDelegate;
} else {
if (!keys.containsKey(k)) {
throw 'Route id ($k) not found';
}
key = keys[k]!;
}
// if (_key.listenersLength == 0 && !testMode) {
// throw """You are trying to use contextless navigation without
// a GetMaterialApp or Sint.key.
// If you are testing your app, you can use:
// [Sint.testMode = true], or if you are running your app on
// a physical device or emulator, you must exchange your [MaterialApp]
// for a [GetMaterialApp].
// """;
// }
return key;
}