RouteNode class

Constructors

RouteNode(String path, String originalPath, {RouteNode? parent})

Properties

fullPath → String
no setter
hasChildren → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isRoot → bool
no setter
nodeSegments ↔ List<RouteNode>
getter/setter pair
originalPath ↔ String
getter/setter pair
parent ↔ RouteNode?
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addChild(RouteNode child) → void
findChild(String name) → RouteNode?
matches(String name) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited