PageRedirect class

Constructors

PageRedirect({SintPage? route, SintPage? unknownRoute, bool isUnknown = false, RouteSettings? settings})

Properties

hashCode int
The hash code for this object.
no setterinherited
isUnknown bool
getter/setter pair
route SintPage?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings?
getter/setter pair
unknownRoute SintPage?
getter/setter pair

Methods

addPageParameter(SintPage route) → void
getPageToRoute<T>(SintPage rou, SintPage? unk, BuildContext context) SintPageRoute<T>
needRecheck(BuildContext context) bool
check if redirect is needed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited