RouteDecoder class

Constructors

RouteDecoder(List<SintPage> currentTreeBranch, PageSettings? pageSettings)
const
RouteDecoder.fromRoute(String location)
factory

Properties

args → dynamic
no setter
currentChildren → List<SintPage>?
no setter
currentTreeBranch → List<SintPage>
final
hashCode → int
The hash code for this object.
no setteroverride
pageSettings → PageSettings?
final
parameters → Map<String, String>
no setter
pathParams → Map<String, String>
Path (segment) parameters only, e.g. :id in /user/:id (1.5.0).
no setter
queryParams → Map<String, String>
Query parameters only (1.5.0).
no setter
route ↔ SintPage?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

arguments<T>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
routeOrUnknown(SintPage onUnknow) → SintPage
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override