RouteParser constructor

RouteParser({
  1. required List<SintPage> routes,
})

Takes a snapshot of the supplied flat route table. Subsequent changes should use routes, addRoute, or removeRoute; changing the original list does not change this parser's table.

Implementation

RouteParser({
  required List<SintPage> routes,
}) {
  this.routes = _RouteList(routes, () => _indexDirty = true);
}