RouteTree class

Constructors

RouteTree()

Properties

hashCode → int
The hash code for this object.
no setterinherited
matcher → RouteMatcher
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tree → Map<String, SintPage>
final

Methods

addRoute(SintPage route) → void
addRoutes(List<SintPage> routes) → void
handleChild(SintPage route) → void
matchRoute(String path) → RouteTreeResult?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRoute(SintPage route) → void
removeRoutes(List<SintPage> routes) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → RouteTree
final