RouteTreeResult class

Constructors

RouteTreeResult({required SintPage? route, required RouteMatchResult matchResult})

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchResult → RouteMatchResult
final
route → SintPage?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(String page, Object? arguments) → RouteTreeResult
copyWith({SintPage? route, RouteMatchResult? matchResult}) → RouteTreeResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited