initialRoute property
The initial route of the app, used as fallback when Sint.back() has no route to pop (e.g. after Sint.offNamed replaced the whole stack).
Implementation
final String initialRoute;
The initial route of the app, used as fallback when Sint.back() has no route to pop (e.g. after Sint.offNamed replaced the whole stack).
final String initialRoute;