SintModalBottomSheetLayout class

Inheritance

Constructors

SintModalBottomSheetLayout(double progress, bool isScrollControlled)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isScrollControlled → bool
final
progress → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstraintsForChild(BoxConstraints constraints) → BoxConstraints
The constraints for the child given the incoming constraints.
override
getPositionForChild(Size size, Size childSize) → Offset
The position where the child should be placed.
override
getSize(BoxConstraints constraints) → Size
The size of this object given the incoming constraints.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRelayout(covariant SintModalBottomSheetLayout oldDelegate) → bool
Called whenever a new instance of the custom layout delegate class is provided to the RenderCustomSingleChildLayoutBox object, or any time that a new CustomSingleChildLayout object is created with a new instance of the custom layout delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited