theme property
An SDK theme that temporarily selects the legacy Material host.
Implementation
@Deprecated(_legacyThemeNotice)
final legacy.ThemeData? theme;
An SDK theme that temporarily selects the legacy Material host.
@Deprecated(_legacyThemeNotice)
final legacy.ThemeData? theme;