SintDesign enum

The design-system host used by SintApp.

Inheritance
Available extensions

Values

auto → const SintDesign

Uses Cupertino on iOS and Material on all other target platforms.

On the web, Flutter reports the browser's target platform. Use material or cupertino to keep the same presentation across browser platforms.

material → const SintDesign

Uses standalone material_ui on every platform.

cupertino → const SintDesign

Uses standalone cupertino_ui on every platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SintDesign>
A constant List of the values in this enum, in order of their declaration.