SnackbarController class

Constructors

SnackbarController(SintSnackBar snackbar)

Properties

controller ↔ AnimationController
The animation controller that the route uses to drive the transitions.
latefinal
future → Future<void>
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<SintSnackBarState>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snackbar → SintSnackBar
final

Methods

close({bool withAnimations = true}) → Future<void>
Close the snackbar with animation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOverlay() → void
show() → Future<void>
Adds SintSnackBar to a view queue. Only one SintSnackBar will be displayed at a time, and this method returns a future to when the snackbar disappears.
showOverlay() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isSnackbarBeingShown → bool
no setter

Static Methods

cancelAllSnackbars() → Future<void>
closeCurrentSnackbar() → Future<void>