IntlHost class

Constructors

IntlHost()

Properties

fallbackLocale ↔ Locale?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ Locale?
getter/setter pair
pathTranslator ↔ PathTranslator?
URL path translator built from translations when translateEndpoints is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translations ↔ Map<String, Map<String, String>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited