navigation/sint_navigation library
Classes
- CircularRevealClipper
- CircularRevealTransition
- ConfigData
- Configuration for SINT's current SDK design-system host.
- CustomTransition
- DirectionalityDragGestureRecognizer
- FadeInTransition
- LeftToRightFadeTransition
- MiddlewareRunner
- NoTransition
- PageRedirect
- PageSettings
- PathDecoded
- RightToLeftFadeTransition
- RouteData
- This is basically a util for rules about 'what a route is'
- RouteDecoder
- RouteMatcher
- RouteMatchResult
- A class representing the result of a route matching operation.
- RouteNode
- RouteParser
-
RouterReportManager<
T> - RouteTree
- RouteTreeResult
- Routing
- SintApp
- A SINT application with standalone Material and Cupertino design systems.
- SintAppBar
- A Sint-aware AppBar that integrates with Sint's routing stack.
-
SintBackGestureDetector<
T> -
SintBackGestureDetectorState<
T> - SintCupertinoApp
- A SINT application using Cupertino widgets bundled with the Flutter SDK.
- SintDelegate
-
SintDialogRoute<
T> - SintInformationParser
- SintMaterialApp
- A SINT application using Material widgets bundled with the Flutter SDK.
- SintMiddleware
- The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
- SintModalBottomSheetLayout
-
SintModalBottomSheetRoute<
T> - A modal bottom-sheet route using Material widgets from the Flutter SDK.
-
SintPage<
T> -
SintPageRoute<
T> - SintRoot
- SintRootState
- SintSnackBar
- SintSnackBarState
- SintSnackBarStyle
-
Global default style for
Sint.snackbar()andSint.rawSnackbar(). - SintTestMode
- SintUrlStrategy
- Public, explicit control over the web URL strategy (1.5.0).
- SizeTransitions
- SlideDownTransition
- SlideLeftTransition
- SlideRightTransition
- SlideTopTransition
- SnackbarController
- SnackBarQueue
- ZoomInTransition
Enums
- PopMode
- Enables the user to customize the intended pop behavior
- PreventDuplicateHandlingMode
- Enables the user to customize the behavior when pushing multiple router that shouldn't be duplicates
- RowStyle
- SintDesign
- The design-system host used by SintApp.
- SnackbarStatus
-
Indicates Status of snackbar
SnackbarStatus.OPENSnack is fully open,SnackbarStatus.CLOSEDSnackbar has closed,SnackbarStatus.OPENINGStarts with the opening animation and ends with the full snackbar display,SnackbarStatus.CLOSINGStarts with the closing animation and ends with the full snackbar dispose - SnackHoverState
- Indicates if the mouse entered or exited
- SnackPosition
-
Indicates if snack is going to start at the
TOPor at theBOTTOM - SnackStyle
- Indicates if snack will be attached to the edge of the screen or not
- Transition
Mixins
Extensions
Constants
- kBackGestureWidth → const double
- kMaxMidSwipePageForwardAnimationTime → const int
- DEPRECATED const double kMinFlingVelocity = 1; // Screen widths per second.
- kMaxPageBackAnimationTime → const int
Properties
-
It replaces the Flutter Navigator, but needs no context.
You can to use navigator.push(YourRoute()) rather
Navigator.push(context, YourRoute());
no setter
Functions
-
extractRouteName(
Route? route) → String? - Extracts the name of a route based on it's instance type or null if not possible.
-
removeLastHistory(
String? url) → void -
resolveRoutePath(
String page, {Map< String, String> ? pathParams, Map<String, String> ? queryParams}) → String - Builds a concrete URL from a route template (1.5.0).
-
sanitizeRouteInformationState(
Object? state) → Object? -
Returns
stateunchanged when its complete object graph is JSON-safe. -
setUrlStrategy(
) → void
Typedefs
- GetPageBuilder = SintPageBuilder
-
GetRouteAwarePageBuilder<
T> = SintRouteAwarePageBuilder< T> - OnHover = void Function(SintSnackBar snack, SnackHoverState snackHoverState)
- OnTap = void Function(SintSnackBar snack)
- SintPageBuilder = Widget Function()
-
SintRouteAwarePageBuilder<
T> = Widget Function([PageRoute< T> ? route]) - SnackbarStatusCallback = void Function(SnackbarStatus? status)