RouteData class

This is basically a util for rules about 'what a route is'

Constructors

RouteData({required String? name, required bool isSintPageRoute, required bool isBottomSheet, required bool isDialog})
const
RouteData.ofRoute(Route? route)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isBottomSheet bool
final
isDialog bool
final
isGetPageRoute bool
no setter
isSintPageRoute bool
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited