RouteParser class
Constructors
-
RouteParser({required List<
SintPage> routes}) -
Takes a snapshot of the supplied flat route table. Subsequent changes
should use
routes, addRoute, or removeRoute; changing the original list does not change this parser's table.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
↔ List<
SintPage> -
Mutable registered routes. Every mutation, including replacing or
reordering entries without changing the length, invalidates the index.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRoute<
T> (SintPage< T> route) → void -
addRoutes<
T> (List< SintPage< sintPages) → voidT> > -
matchRoute(
String name, {PageSettings? arguments}) → RouteDecoder -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeRoute<
T> (SintPage< T> route) → void -
removeRoutes<
T> (List< SintPage< sintPages) → voidT> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited