RouteTemplate class
Shared syntax for matching routes and resolving navigation templates. This is internal to the router; parameter values are encoded only when a template is resolved, never while its matching expression is compiled.
Constructors
- RouteTemplate.parse(String source, {bool allowQuery = true})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → String
-
final
-
tokens
→ List<
RouteTemplateToken> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Map< String, String> parameters) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compile(
String source) → PathDecoded